/* 
 * Node Controller
 */

// Defines namespace for Controller classes
var Controller = Controller || {};

Controller.currentController;
//Base URL: Based on current device
Controller.baseURL;

Controller.fileSystem;

Controller.reflectoryContainer;

Controller.currentReflectory;

Controller.currentLanguage;

/**
 * Constructor for NodeController
 */
Controller.NodeController = function () {
    that = this;

    this.baseURL = Controller.baseURL;

    this.reflectoryContainer = Controller.reflectoryContainer;
    this.currentNode         = this.reflectoryContainer.findReflectoryByLanguage(Controller.currentLanguage).findNodebyId("n_0");
    this.currentReflectory = this.reflectoryContainer.findReflectoryByLanguage(Controller.currentLanguage);
    this.fileSystem = null;
    this.currentAudio = null;
    this.audioStatus = null;
    this.sliderStatus = null;

    if (Controller.clientType === "phonegap")
        this.clientType = true;

    this.view = new NodeView(this);
    this.updateNodeContent();

};

/**
 * Sets currentNode to node
 */
Controller.NodeController.prototype.setCurrentNode = function (node)
{
    this.currentNode = node;
};


/*
 * Updates views content according to the current node of NodeController
 */
Controller.NodeController.prototype.updateNodeContent = function ()
{
    this.view.refresh();
    this.view.render();
};

/**
 * Audio handler in case of mobile device
 */
Controller.NodeController.prototype.audioHandler = function ()
{
    var that = this;
    switch (this.audioStatus) {

        case null:

            var help = Controller.baseURL + this.currentNode.audio;
            help = help.replace('file://', '');

            //  this.currentAudio = new Media(Controller.
            //        baseURL + this.currentNode.audio, onSuccess, onError);
            this.currentAudio = new Media(help, onSuccess, onError);
            this.sliderStatus = setInterval(this.updateMusicSlider, 500);

            //If player is finished show descicions and stop current audio
            function onSuccess() {
                if (that.currentAudio !== null)
                {
                    console.log("playAudio():Audio Success");
                    that.currentAudio.pause();
                    that.currentAudio.seekTo(0);
                    that.audioStatus = "stop";
                    $("#slider").val(0).slider("refresh");
                    $("#audiocontrol").attr("src", "./img/click.png");
                    that.currentNode.isAudioFinished = true;
                    that.view.showDecisions();
                }
            }

            function onError() {
                console.log("playAudio():Audio FAIL");
            }
            $("#audiocontrol").attr("src", "./img/pause.png");
            this.audioStatus = "running";
            this.currentAudio.play();
            break;

        case "stop":
            $("#audiocontrol").attr("src", "./img/pause.png");
            this.audioStatus = "running";
            this.currentAudio.play();
            break;

        case "running":
            $("#audiocontrol").attr("src", "./img/click.png");
            this.currentAudio.pause();
            this.audioStatus = "stop";
            break;
    }

};

Controller.NodeController.prototype.clearInterval = function ()
{
    clearInterval(this.sliderStatus);
};

Controller.NodeController.prototype.moveSlider = function (position)
{
    if (this.currentAudio !== null)
        this.sliderStatus = setInterval(this.updateMusicSlider, 500);
    this.currentAudio.seekTo(position);
};

// Event handler for click events
Controller.NodeController.prototype.eventHandler = function (event)
{
    if (this.currentAudio !== null) {
        clearInterval(this.sliderStatus);
        this.currentAudio.stop();
        this.currentAudio.release();
        this.audioStatus = null;
        this.currentAudio = null;
    }
    //puts current node to NodeHistory array
    this.reflectoryContainer.addToNodeHistory(this.currentNode);

    if ($(event.currentTarget).data("target") === "n_-1") {
        Controller.currentController = new Controller.EndScreenController();
    }
    else {
        // changes current node to new node
        this.currentNode = this.reflectoryContainer.
                findReflectoryByLanguage(Controller.currentLanguage).
                findNodebyId($(event.currentTarget).data("target"));

        //  this.updateNodeContent();
        this.view = new NodeView(this);
        this.updateNodeContent();
    }
};

Controller.NodeController.prototype.updateMusicSlider = function ()
{
    // get media position
    that.currentAudio.getCurrentPosition(
            // success callback
                    function (position) {
                        if (position > -1) {
                            $("#slider").attr("max", that.currentAudio.getDuration());
                            console.log((position) + " sec");
                            $("#slider").val(position).slider("refresh");
                        }
                    },
                    // error callback
                            function (e) {
                                console.log("Error getting pos=" + e);
                            }
                    );
                };


